@@ -5,10 +5,14 @@ import marko
 from jinja2 import Template
 from marko.ext.gfm import GFM
 from marko.html_renderer import HTMLRenderer
+from frictionless import Resource, Detector
 from . import config
 
 
 class LivemarkRendererMixin(HTMLRenderer):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.__counter = 0
 
     # Render
 
@@ -28,16 +32,28 @@ class LivemarkRendererMixin(HTMLRenderer):
 
     def render_fenced_code(self, element):
         if "table" in element.lang or "table" in element.extra:
-            path = str(element.children[0].children).strip()
+            spec_yaml = str(element.children[0].children).strip()
+            spec_python = yaml.safe_load(spec_yaml)
+            spec_python["licenseKey"] = "non-commercial-and-evaluation"
+            detector = Detector(field_float_numbers=True)
+            resource = Resource(spec_python.get("data", []), detector=detector)
+            header, *lists = resource.to_snap(json=True)
+            spec_python["colHeaders"] = header
+            spec_python["data"] = lists
+            spec = json.dumps(spec_python, ensure_ascii=False)
+            spec = spec.replace("'", "\\'")
             template = Template(config.TABLE)
-            text = template.render(path=path, id="table-example")
+            self.__counter += 1
+            text = template.render(spec=spec, elem=f"livemark-{self.__counter}")
             return text
         if "chart" in element.lang or "chart" in element.extra:
             spec_yaml = str(element.children[0].children).strip()
             spec_python = yaml.safe_load(spec_yaml)
-            spec = json.dumps(spec_python)
+            spec = json.dumps(spec_python, ensure_ascii=False)
+            spec = spec.replace("'", "\\'")
             template = Template(config.CHART)
-            text = template.render(spec=spec, id="chart-example")
+            self.__counter += 1
+            text = template.render(spec=spec, elem=f"livemark-{self.__counter}")
             return text
         return super().render_fenced_code(element)
 
